@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '2.91';
+our $VERSION = '3.00';
 
 # AUTHORITY
 
@@ -870,7 +870,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-2.91
+3.00
 
 =cut
 
@@ -1793,7 +1793,7 @@ I<Since C<2.55>>
 
   use Venus 'config';
 
-  my $config = config {}, 'from_perl', '{"data"=>1}';
+  my $config = config {}, 'read_perl', '{"data"=>1}';
 
   # bless({...}, 'Venus::Config')
 
